/* ******************************************************************** */
/*  		                       T.D. n°5 				  	  	    */
/* 		   			ESTIMATIONS PONCTUELLES & PAR INTERVALLE            */
/*						TEST DE CONFORMITE A UN STANDARD  	        	*/
/*														                */
/* ******************************************************************** */


/* ******************************************** */
/*  PARTIE 0  		        	                */
/*  Importation des données                     */
/*	Et création de nouvelles variables	        */
/* ******************************************** */

/* 0.1. Créez une nouvelle bibliothèque « TD ». Créez un nouveau folder "TD5" dans l'onglet "Files(Home)". Importez les données à partir du fichier .csv : “Happiness2017.csv” (PROC IMPORT). */

LIBNAME TD '/home/u43518629';

/* (via sas on demand) */

PROC IMPORT DATAFILE= '/home/u43518629/TD5/Happiness2017.csv'
	DBMS=CSV
	OUT=TD.bdd
	replace;
	delimiter = ';';
RUN;

/* 0.2. Combien y a-t-il d’observations et de variables ? Affichez un résumé de la table. (PROC CONTENT). */

PROC CONTENTS DATA=TD.bdd;
RUN;


/* 0.3.1.	Créez une variable catégorielle « happy_cat » à partir de la variable « Happiness_Score ». */

DATA TD.bdd;
	SET TD.bdd;
	LENGTH happy_cat $ 20;
		IF Happiness_Score <4 THEN happy_cat = "unhappy";
			ELSE IF Happiness_Score >=4 AND Happiness_Score < 6 THEN happy_cat = "moderate";
		ELSE happy_cat = "happy";
RUN;


/* 0.3.2.	Faites de même à partir de la variable « generosity ». */

DATA TD.bdd;
	SET TD.bdd;
	LENGTH generosity_cat $ 20;
		IF Generosity <0.05 THEN generosity_cat = "very_selfish";
			ELSE IF Generosity >=0.05 AND Generosity < 0.1 THEN generosity_cat = "bit_selfish";
			ELSE IF Generosity >=0.1 AND Generosity < 0.15 THEN generosity_cat = "indifferent";
			ELSE IF Generosity >=0.15 AND Generosity < 0.20 THEN generosity_cat = "generous";
		ELSE generosity_cat = "very_generous";
RUN;

/* ******************************************** */
/* PARTIE 1  			       					*/
/* Estimations ponctuelles & par intervalle     */
/* ******************************************** */

/* 1.1 Quelle est la modalité de la variable « happy_cat » la plus fréquente ? (PROC FREQ) */

PROC FREQ data = TD.bdd; 
	tables happy_cat;
RUN;


/* 1.2 Croisons les variables « happy_cat » et « generosity_cat ». A quelle modalité de "generosity_cat" correspond la plus importante proportion de "happy" ? (PROC FREQ) */

PROC FREQ data = TD.bdd;
	tables happy_cat * generosity_cat; 
RUN; 


/* 1.3.1.	En ne considérant que les pays possédant une grande liberté (« Freedom » > 0,5) quel est l’intervalle de confiance à 99% de l’estimation de la proportion de «neutral» (variable « happy_cat ») dans notre échantillon ? (PROC FREQ) */

PROC FREQ data = TD.bdd;
	tables happy_cat / binomial (level='neutral') alpha=0.01;
	where Freedom > 0.5;
RUN;


/* 1.3.2.	Quel est la fréquence de la modalité "happy" de la variable "happy_cat" et son IC à 95% ? */

PROC FREQ data = TD.bdd;
	tables happy_cat / binomial (level='happy') alpha=0.05;
RUN;


/* 1.4	Quelle est la moyenne mondiale de la variable « Happiness_Score », ainsi que sa variance ? (PROC MEAN) */

PROC MEANS data = TD.bdd mean var;    
	var Happiness_Score;  
RUN;


/* 1.5	Quelle est la moyenne du « happiness_score » pour la catégorie « indifferent » de « generosity_cat » en précisant les bornes supérieurs et inférieurs de son intervalle de confiance à 99% ? (PROC MEAN).
Par rapport au résultat obtenu à la question précédente, quelle remarque pouvez-vous soulevez ? */

PROC MEANS data = TD.bdd MEAN CLM alpha=0.05;
	class generosity_cat;
	var Happiness_Score;
RUN;


/* 1.6 Quelle est la moyenne et l’écart type du score du bonheur pour les pays dont « Economy_GDP_Per_Capita" est inférieure à 0.8 ? (PROC MEAN) */

PROC MEANS data= TD.bdd mean std;    
    var Happiness_Score;
    WHERE Economy_GDP_per_Capita < 0.8;
RUN;




/* ******************************************************** */
/*  PARTIE 2  			       						  	    */
/*  Test centraux et de conformité à un standard   	        */
/*														    */
/* ******************************************************** */

/* 2.1. Sachant qu’en 2015 le score mondial de bonheur était de 5.21, 
est-ce que ce score a évolué entre 2015 et 2017 ? Pour cela vous ne considérerez que les pays 
ayant une generosity >0.15  (PROC TTEST) */

PROC MEANS DATA =TD.bdd N;
	VAR Happiness_Score;
	WHERE Generosity>0.15;
RUN;
/* il y a suffisament de pays pour faire le test*/

Proc ttest data=TD.bdd h0=5.21;
	VAR Happiness_Score;
	WHERE Generosity>0.15;
RUN;

/* p>0.05 => on ne rejette pas H0 => le score de bonheur n'a pas évolué*/

/* 2.2. Calculez la variance du score de bonheur de 2017.*/

PROC MEANS DATA = TD.bdd CLM VAR;
	var Happiness_Score;
RUN;

/* var=1.303 */

/* 2.3.	Même question qu’en 1 mais en utilisant la connaissance de la variance 
du score de bonheur.*/

PROC MEANS DATA =TD.bdd N MEAN;
	VAR Happiness_Score;
	WHERE Generosity>0.15;
RUN;

/* n=119 m=5.414*/

proc iml;
	m0=5.21;
	m=5.414;
	var=1.303;
	qlt=quantile('NORMALE',.975);
	n=119;
	diff=m-m0;
	print diff;
	comp=qlt*var/sqrt(n);
	print comp;
	quit;


/* 5.414-5.21= 0.204 < 1.96*1.303/sqrt(119)= 0,234 => on ne rejette pas H0 
=> le score de bonheur mondial n'a pas évolué/*

/* 2.4. Tracer l’histogramme des distributions de l’indice de générosité des pays. 
Qu’observez-vous ?*/

Proc univariate data=TD.bdd noprint;
	histogram Generosity;
RUN;


/* 2.5. Peut-on considérer que la distribution de l’indice de générosité suit une loi normale ?*/

Proc univariate normal plot data=TD.bdd;
	var generosity;
RUN;

/* p<0,05 => on rejette H0=> on ne peut pas considérer que la distribution est normale



/* ************************************ */
/*  PARTIE 3  			      	  	    */
/*  ANOVA et PROPORTION  	            */
/*									    */
/* ************************************ */

/* 3.1. Dystopia_Residual  est-elle significativement différente entre les pays de chaque zone au risque 5% ? 10% ? (PROC ANOVA ou PROC GLM)
Attention : quelle supposition fait on dans le cadre d’une ANOVA ? Vérifiez le grâce au test adéquat. */

/* Supposition : test de shapiro pour tester la normalité de la variable Dystopia_Residual */
PROC UNIVARIATE DATA= TD.bdd NORMAL PLOT;
	var Dystopia_Residual;
RUN;

PROC ANOVA data = TD.bdd;
	class Region;
	model Dystopia_Residual = Region;
	means Region;
RUN;


PROC ANOVA data = TD.bdd;
	class Region;
	model Dystopia_Residual = Region;
	means Region / alpha =0.1 ;
RUN;

PROC GLM data= TD.bdd;
	class Region;
	model Dystopia_Residual = Region;
	means Region;
RUN;


/* 3.2. Refaire le test sans supposer que la variable Dystopia_Residual suit une loi normale. (PROC NPAR1WAY) */

PROC NPAR1WAY data = TD.bdd;
	class Region;
	var Freedom;
RUN;


/* 3.3. Peut-on affirmer avec une certitude de 95% que les proportions des régiosn sont toutes identiques ?  (PROC FREQ) */

PROC FREQ data = TD.bdd;
	tables Region / chisq testp = (10 10 10 10 10 10 10 10 10 10);
RUN; 




/* ******************************************************** */
/*  PARTIE 4  			       						  	    */
/*  Test d’indépendance entre deux variables aléatoires  	*/
/*														    */
/* ******************************************************** */


/* 4.1. Peut-on conclure à un lien entre la variable "Economy_GDP_per_Capita" et la variable “generosity” ? (PROC CORR) */

PROC CORR DATA = TD.bdd;
	var Economy_GDP_per_Capita Generosity;
RUN;


/* 4.2. Idem pour les variables "happy_cat" et “Dystopia_Residual” ? (PROC ANOVA) */

PROC ANOVA data = TD.bdd;
	class happy_cat;
	model Dystopia_Residual = happy_cat;
	means happy_cat;
RUN;


/* 4.3. Enfin, faites de même pour les variables happy_cathappy_cat et “generosity_cat” (PROC FREQ + option CHISQ).  */

PROC FREQ DATA = TD.bdd;
	tables happy_cat*generosity_cat / chisq;
RUN;